@@ -1,13 +1,13 @@
 ;;; org-edna.el --- Extensible Dependencies 'N' Actions -*- lexical-binding: t; -*-
 
-;; Copyright (C) 2017-2018 Free Software Foundation, Inc.
+;; Copyright (C) 2017-2020 Free Software Foundation, Inc.
 
 ;; Author: Ian Dunn <dunni@gnu.org>
 ;; Maintainer: Ian Dunn <dunni@gnu.org>
 ;; Keywords: convenience, text, org
 ;; URL: https://savannah.nongnu.org/projects/org-edna-el/
 ;; Package-Requires: ((emacs "25.1") (seq "2.19") (org "9.0.5"))
-;; Version: 1.0.2
+;; Version: 1.1.1
 
 ;; This file is part of GNU Emacs.
 
@@ -688,24 +688,37 @@ This shouldn't be run from outside of `org-blocker-hook'."
       t)))
 
 ;;;###autoload
-(defun org-edna-load ()
+(defun org-edna--load ()
   "Setup the hooks necessary for Org Edna to run.
 
 This means adding to `org-trigger-hook' and `org-blocker-hook'."
-  (interactive)
   (add-hook 'org-trigger-hook 'org-edna-trigger-function)
   (add-hook 'org-blocker-hook 'org-edna-blocker-function))
 
+(define-obsolete-function-alias 'org-edna-load 'org-edna-mode)
+
 ;;;###autoload
-(defun org-edna-unload ()
+(defun org-edna--unload ()
   "Unload Org Edna.
 
 Remove Edna's workers from `org-trigger-hook' and
 `org-blocker-hook'."
-  (interactive)
   (remove-hook 'org-trigger-hook 'org-edna-trigger-function)
   (remove-hook 'org-blocker-hook 'org-edna-blocker-function))
 
+(define-obsolete-function-alias 'org-edna-unload 'org-edna-mode)
+
+;;;###autoload
+(define-minor-mode org-edna-mode
+  "Toggle Org Edna mode."
+  :init-value nil
+  :lighter " edna"
+  :group 'org-edna
+  :global t
+  (if org-edna-mode
+      (org-edna--load)
+    (org-edna--unload)))
+
 
 ;;; Finders
 
@@ -971,8 +984,8 @@ All arguments are symbols, unless noted otherwise.
         ('step-down
          (setq targets
                (org-with-wide-buffer
-                (org-goto-first-child)
-                (org-edna-collect-current-level (org-edna-self-marker) nil nil t))))
+                (when (org-goto-first-child)
+                  (org-edna-collect-current-level (org-edna-self-marker) nil nil t)))))
         ('todo-only
          ;; Remove any entry without a TODO keyword, or with a DONE keyword
          (cl-pushnew
